table

Function table 

pub fn table<'a, Column, Row, Message, Theme>(
    header: Id,
    body: Id,
    columns: &'a [Column],
    rows: &'a [Row],
    on_sync: fn(AbsoluteOffset) -> Message,
) -> Table<'a, Column, Row, Message, Theme>
where Theme: Catalog + Catalog,
Creates a new Table with the provided Column definitions and Row data.

on_sync is needed to keep the header & footer scrollables in sync with the body scrollable. It is up to the consumer to emit a scroll_to operation from update when this message is received.