Creates a new Table with the provided Column definitions
and Row data.
on_sync is needed to keep the header & footer scrollables in sync with
the body scrollable. It is up to the consumer to emit a scroll_to operation
from update when this message is received.